/*
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements. See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership. The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License. You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied. See the License for the
* specific language governing permissions and limitations
* under the License.
*/

package org.apache.taverna.reference.impl;

import org.apache.taverna.reference.T2ReferenceGenerator;

/**
 * Simple implementation of T2ReferenceGenerator intended to be injected into
 * the service layers for integration testing. Exposes a namespace property
 * which can be configured through spring and allocates local parts based on an
 * integer counter - this is only guaranteed to be unique within a single
 * instance of this object so isn't suitable for real production use. For proper
 * usage use an implementation tied to the backing store you're putting t2
 * reference objects into.
 * 
 * @author Tom Oinn
 */
public class SimpleT2ReferenceGenerator extends AbstractT2ReferenceGenerator implements T2ReferenceGenerator {
	private String namespace = "testNS";
	private String localPrefix = "test";
	private int counter = 0;

	/**
	 * Set the namespace for identifiers generated by this class as a string
	 * 
	 * @param newNamespace
	 *            the namespace to use
	 */
	public void setNamespace(String newNamespace) {
		this.namespace = newNamespace;
	}

	/**
	 * Get the namespace for identifiers generated by this class
	 */
	@Override
	public String getNamespace() {
		return namespace;
	}

	@Override
	protected synchronized String getNextLocalPart() {
		return localPrefix + (counter++);
	}
}
